California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 89 - POLITICAL CAMPAIGNS. PUBLIC FINANCING. CORPORATE TAX INCREASE. CONTRIBUTION AND EXPENDITURE LIMITS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287451 | CALIFORNIANS FOR FAIR ELECTIONS: YES ON 89, MAJOR FUNDING BY CALIFORNIA NURSES ASSOCIATION AND CALIFORNIA NURSES ASSOCIATION INITIATIVE PAC, WITH SUPPORT FROM CONCERNED CITIZENS AND BUSINESSPERSONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1286190 | TAXPAYERS FOR FAIR ELECTIONS/ NO ON 89, A COALITION OF BUSINESS AND TAXPAYER ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288245 | CLEAN MONEY NOW - YES ON 89 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1292396 | COMMON CAUSE FOR PROPOSITION 89 | SUPPORT